@@ -33,6 +33,7 @@ __extern int execlp(const char *, const char *, ...);
 __extern int execle(const char *, const char *, ...);
 __extern int execlpe(const char *, const char *, ...);
 
+__extern int nice(int);
 __extern int setuid(uid_t);
 __extern uid_t getuid(void);
 __extern int seteuid(uid_t);
@@ -140,14 +141,15 @@ __extern int optind, opterr, optopt;
 
 __extern int isatty(int);
 
+__extern unsigned int __page_size;
 static __inline__ int getpagesize(void)
 {
-	extern unsigned int __page_size;
 	return __page_size;
 }
+
+__extern unsigned int __page_shift;
 static __inline__ int __getpageshift(void)
 {
-	extern unsigned int __page_shift;
 	return __page_shift;
 }
 
